@@ -19,7 +19,7 @@ impl WaitAction {
 }
 
 impl Action for WaitAction {
-    fn add(&mut self, actor: Entity, world: &mut World, _commands: &mut ActionCommands) {
+    fn start(&mut self, actor: Entity, world: &mut World, _commands: &mut ActionCommands) {
         world.entity_mut(actor).insert(Wait(self.0));
     }
 
@@ -39,7 +39,7 @@ fn wait(mut wait_q: Query<(Entity, &mut Wait)>, time: Res<Time>, mut commands: C
     for (actor, mut wait) in wait_q.iter_mut() {
         wait.0 -= time.delta_seconds();
         if wait.0 <= 0.0 {
-            commands.next_action(actor);
+            commands.action(actor).next();
         }
     }
 }
